@@ -5,9 +5,10 @@ package WebService::Simplenote;
 # TODO: cache authentication token between runs, use LWP cookie_jar for auth token
 # TODO: Net::HTTP::Spore?
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 use v5.10;
+use open qw(:std :utf8);
 use Moose;
 use MooseX::Types::Path::Class;
 use JSON;
@@ -40,6 +41,13 @@ has no_server_updates => (
     default  => 0,
 );
 
+has page_size => (
+    is       => 'ro',
+    isa      => 'Int',
+    required => 1,
+    default  => 20,
+);
+
 has logger => (
     is       => 'ro',
     isa      => 'Object',
@@ -85,24 +93,59 @@ sub _build_token {
     return $response->content;
 }
 
-# Get list of notes from simplenote server
-# TODO since, mark, length options
-sub get_remote_index {
-    my $self  = shift;
-    my $notes = {};
+sub _get_remote_index_page {
+    my ( $self, $mark ) = @_;
+
+    my $notes;
+
+    my $req_uri = sprintf '%s/index?auth=%s&email=%s&length=%i',
+      $self->_uri, $self->token, $self->email, $self->page_size;
+
+    if ( defined $mark ) {
+        $self->logger->debug( 'Network: retrieving next page' );
+        $req_uri .= '&mark=' . $mark;
+    }
 
-    $self->logger->debug( 'Network: get note index' );
-    my $req_uri  = sprintf '%s/index?auth=%s&email=%s', $self->_uri, $self->token, $self->email;
     my $response = $self->_ua->get( $req_uri );
     my $index    = decode_json( $response->content );
 
-    $self->logger->debugf( 'Network: Index returned [%s] notes', $index->{count} );
+    if ( $index->{count} > 0 ) {
+        $self->logger->debugf( 'Network: Index returned [%s] notes', $index->{count} );
 
-    # iterate through notes in index and load into hash
-    foreach my $i ( @{ $index->{data} } ) {
-        $notes->{ $i->{key} } = WebService::Simplenote::Note->new( $i );
+        # iterate through notes in index and load into hash
+        foreach my $i ( @{ $index->{data} } ) {
+            $notes->{ $i->{key} } = WebService::Simplenote::Note->new( $i );
+        }
+
+    } elsif ( $index->{count} == 0 && !exists $index->{mark} ) {
+        $self->logger->debugf( 'Network: No more pages to retrieve' );
+    } elsif ( $index->{count} == 0 ) {
+        $self->logger->debugf( 'Network: No notes found' );
     }
 
+    if ( exists $index->{mark} ) {
+        return ( $notes, $index->{mark} );
+    }
+
+    return $notes;
+}
+
+# Get list of notes from simplenote server
+# TODO since, mark, length options
+sub get_remote_index {
+    my $self = shift;
+
+    $self->logger->debug( 'Network: getting note index' );
+
+    my ( $notes, $mark ) = $self->_get_remote_index_page;
+
+    while ( defined $mark ) {
+        my $next_page;
+        ( $next_page, $mark ) = $self->_get_remote_index_page( $mark );
+        @$notes{ keys %$next_page } = values %$next_page;
+    }
+
+    $self->logger->infof( 'Network: found %i remote notes', scalar keys %$notes );
     return $notes;
 }
 
@@ -217,7 +260,7 @@ WebService::Simplenote - Note-taking through simplenoteapp.com
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
@@ -248,8 +291,8 @@ version 0.1.1
 
 =head1 DESCRIPTION
 
-This module proves API access to the cloud-based note software at
-L<https://simplenoteapp.com|Simplenote>.
+This module proves v2.1.5 API access to the cloud-based note software at
+L<Simplenote|https://simplenoteapp.com>.
 
 =head1 ERRORS
 
